#
# spec file for package rebootmgr
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if ! %{defined _distconfdir}
  %define _distconfdir %{_sysconfdir}
  %define with_config 1
%else
  %define with_config 0
%endif

Name:           rebootmgr
Version:        1.3
Release:        150500.1.3
Summary:        Automatic controlled reboot during a maintenance window
License:        GPL-2.0-only AND LGPL-2.1-or-later
Group:          System/Base
URL:            https://github.com/SUSE/rebootmgr
Source:         %{name}-%{version}.tar.xz
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(libeconf)

%description
RebootManager is a dbus service to execute a controlled reboot after updates in a defined maintenance window.

If you updated a system with e.g. transactional updates or a kernel update was applied, you can tell rebootmgrd with rebootmgrctl, that the machine should be reboot at the next possible time. This can either be immeaditly or during a defined maintenance window.

%prep
%setup -q

%build
%configure
make %{?_smp_mflags}

%install
%make_install
ln -sf service %{buildroot}%{_sbindir}/rcrebootmgr
if [ ! -d %{buildroot}%{_distconfdir} ]; then
    mkdir -p %{buildroot}%{_distconfdir}
    mv %{buildroot}%{_sysconfdir}/rebootmgr.conf %{buildroot}%{_distconfdir}
fi
%fdupes %{buildroot}%{_mandir}

%pre
%service_add_pre rebootmgr.service
test -f /etc/rebootmgr.conf.rpmsave && mv -v /etc/rebootmgr.conf.rpmsave /etc/rebootmgr.conf.rpmsave.old ||:

%post
%service_add_post rebootmgr.service

%preun
%service_del_preun rebootmgr.service

%postun
%service_del_postun rebootmgr.service

%posttrans
test -f /etc/rebootmgr.conf.rpmsave && mv -v /etc/rebootmgr.conf.rpmsave /etc/rebootmgr.conf ||:

%files
%license COPYING COPYING.LIB
%doc NEWS
%dir %{_sysconfdir}/dbus-1/system.d
%if %{with_config}
%config %{_sysconfdir}/rebootmgr.conf
%else
%{_distconfdir}/rebootmgr.conf
%endif
%config %{_sysconfdir}/dbus-1/system.d/org.opensuse.RebootMgr.conf
%{_prefix}/lib/systemd/system/rebootmgr.service
%{_sbindir}/rebootmgrctl
%{_sbindir}/rebootmgrd
%{_sbindir}/rcrebootmgr
%{_datadir}/dbus-1/interfaces/org.opensuse.RebootMgr.xml
%{_mandir}/man1/rebootmgrctl.1%{?ext_man}
%{_mandir}/man5/rebootmgr.conf.5%{?ext_man}
%{_mandir}/man8/rebootmgrd.8%{?ext_man}
%{_mandir}/man8/org.opensuse.RebootMgr.conf.8%{?ext_man}
%{_mandir}/man8/rebootmgr.service.8%{?ext_man}

%changelog
* Wed Jul  1 2020 kukuk@suse.com
- Update to version 1.3
  - Fix documentation of is-active return  value [bsc#1173484]
  - Fix crash if rebootmgrd is already running
  - Fix systemctl restart
* Mon Jun  8 2020 kukuk@suse.com
- Update to version 1.2
  - depend on dbus and not network as we disabled etcd support
    [bsc#1172518]
* Thu Apr 30 2020 kukuk@suse.com
- Update to version 1.1
  - fix systemd and tmpfiles.d directory path
* Thu Apr 30 2020 kukuk@suse.com
- Use official tar archive
* Mon Apr 27 2020 kukuk@suse.com
- Adjust BuildRequires
* Mon Apr 27 2020 kukuk@suse.com
- Update to version 1.0
  - Rewrite rebootmgrd to not depend on glib and dbus-glib
* Wed Jan 29 2020 kukuk@suse.com
- Disable ectd support (no current etcd C-library available)
* Wed Nov 27 2019 iforster@suse.com
- Fix %%posttrans script returning an error code
* Mon Nov  4 2019 kukuk@suse.de
- Update to version 0.20.1
  - added a memory allocation check
* Mon Sep  9 2019 kukuk@suse.de
- Fix %%config for backward compatibility
* Fri Sep  6 2019 kukuk@suse.de
- Update to version 0.20
  - add support to write changes back to /etc/rebootmgr.conf
* Wed Aug 28 2019 kukuk@suse.de
- Preserve /etc/rebootmgr.conf if modified
* Tue Aug 27 2019 kukuk@suse.de
- Update to version 0.19
  - use libeconf for /usr/etc move
* Thu Jan 17 2019 kukuk@suse.de
- Update to version 0.18
  - allow to compile without etcd support
* Wed Mar 28 2018 kukuk@suse.de
- Update to version 0.17
  - fix some bugs around etcd locks and reboot fast path
* Mon Mar 19 2018 kukuk@suse.de
- Use %%license instead of %%doc [bsc#1082318]
* Wed Jan 10 2018 kukuk@suse.de
- Update to version 0.16
  - fix compile problem with new json-c [bsc#1075329]
* Wed Sep 13 2017 kukuk@suse.de
- Update to version 0.15
  - Adjust for systemd >= 230
* Fri Mar 31 2017 kukuk@suse.de
- Update to version 0.14
  - Allow to have no maintenance window configured [bsc#1031619]
* Wed Mar 15 2017 kukuk@suse.de
- Update to version 0.13
  - Don't reboot outside maintenance window if getting the etcd
    lock takes too long [bsc#1028060]
* Fri Mar  3 2017 kukuk@suse.de
- Update to version 0.12
  - Rewrote reboot code to not block dbus if we wait for etcd locks
    [bsc#1026298]
  - Fix rebootmgr.service dependencies
  - Check input for maintenance window for correct syntax before
    sending to the daemon [bsc#1026220]
* Mon Feb 27 2017 kukuk@suse.de
- Update to version 0.11
  - Implement unlocking of a machine_id not equal to our own [bsc#1026273]
  - Watch for correct key when waiting for lock [bsc#1026274]
* Thu Feb 16 2017 kukuk@suse.de
- Update to version 0.10
  - Fix typos in documentation
  - Fix compilation on 32bit systems
* Tue Feb 14 2017 kukuk@suse.de
- Update to version 0.9
  - Finish rebootmgrctl manual page
* Wed Feb  8 2017 kukuk@suse.de
- Update to version 0.8
  - Implement changing number of hosts holding a lock at the same time
  - Add new and enhance existing manual pages
* Thu Jan 12 2017 kukuk@suse.de
- Update to version 0.7
  - Fix dbus name in systemd service file
* Thu Jan 12 2017 kukuk@suse.de
- Update to version 0.6
  - Add etcd lock support
* Mon Jan  9 2017 kukuk@suse.de
- Update to version 0.5
  - Rewrite for better dbus support
  - Merges typo.patch
* Tue Dec 13 2016 kukuk@suse.de
- Fix typo in executing systemctl
* Wed Nov 23 2016 kukuk@suse.de
- Update to versin 0.3
  - fix path for systemctl
* Wed Nov 23 2016 kukuk@suse.de
- Update to version 0.2
  - implement maintenance window
  - implement rebootmgrctl get-strategy
* Sun Nov 20 2016 kukuk@suse.de
- Initial submission
